pm4py.algo.discovery.ocel.ocdfg.variants package
================================================

Submodules
----------

pm4py.algo.discovery.ocel.ocdfg.variants.classic module
-------------------------------------------------------

.. automodule:: pm4py.algo.discovery.ocel.ocdfg.variants.classic
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.ocel.ocdfg.variants
   :members:
   :undoc-members:
   :show-inheritance:
